@@ -2,6 +2,9 @@
 #include <unistd.h>
 #include "ucspi-proxy.h"
 
+const char filter_connfail_prefix[] = "";
+const char filter_connfail_suffix[] = "\r\n";
+
 static void show(const char* data, ssize_t size, char prefix)
 {
   ssize_t i;
@@ -29,15 +32,12 @@ static void filter_server_data(char* data, ssize_t size)
   write_client(data, size);
 }
 
-const char* filter_name = "ucspi-proxy-log";
-const char* filter_usage = "";
-
 void filter_init(int argc, char** argv)
 {
   if(argc > 0)
     usage("Too many arguments.");
-  add_filter(CLIENT_IN, filter_client_data, 0);
-  add_filter(SERVER_IN, filter_server_data, 0);
+  set_filter(CLIENT_IN, filter_client_data, 0);
+  set_filter(SERVER_FD, filter_server_data, 0);
 }
 
 void filter_deinit(void)
